snapm package
=============

Module contents
---------------

.. automodule:: snapm
    :members:
    :special-members:
    :exclude-members: __dict__, __module__, __weakref__
    :undoc-members:
    :show-inheritance:

Submodules
----------

snapm.manager module
--------------------

.. automodule:: snapm.manager
    :members:
    :special-members:
    :private-members:
    :exclude-members: __dict__, __module__, __weakref__
    :undoc-members:
    :show-inheritance:

snapm.command module
--------------------

.. automodule:: snapm.command
    :members:
    :special-members:
    :private-members:
    :exclude-members: __dict__, __module__, __weakref__
    :undoc-members:
    :show-inheritance:


snapm.report module
-------------------

.. automodule:: snapm.report
    :members:
    :special-members:
    :exclude-members: __dict__, __module__, __weakref__
    :undoc-members:
    :show-inheritance:


snapm.manager.plugins module
----------------------------

.. automodule:: snapm.manager.plugins
    :members:
    :special-members:
    :private-members:
    :exclude-members: __dict__, __module__, __weakref__
    :undoc-members:
    :show-inheritance:


